function [ logProb ] = compute_model_log_probability( this, direction )
% COMPUTE_MODEL_LOG_PROBABILITY
% Computes the probability of the model; direction is a string ('fwd' or
% 'bwd') that indicates if using the forward or backward kinematic model
%
% Authors: Silvia Zuffi, Department of Computer Science, Brown University
% Contact: zuffi@cs.brown.edu
% $Date: 2012 $
% $Revision: $
%
% Copyright 2011-2012, Brown University, Providence, RI. USA
%
%                          All Rights Reserved
%
% All commercial use of this software, whether direct or indirect, is
% strictly prohibited including, without limitation, incorporation into in
% a commercial product, use in a commercial service, or production of other
% artifacts for commercial purposes.
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for research purposes is hereby granted without fee,
% provided that the above copyright notice appears in all copies and that
% both that copyright notice and this permission notice appear in
% supporting documentation, and that the name of the author and Brown
% University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission.
%
% For commercial uses contact the Technology Venture Office of Brown University
%
% THE AUTHOR AND BROWN UNIVERSITY DISCLAIM ALL WARRANTIES WITH REGARD TO
% THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
% FITNESS FOR ANY PARTICULAR PURPOSE.  IN NO EVENT SHALL THE AUTHOR OR
% BROWN UNIVERSITY BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
% DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
% PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
% ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
% THIS SOFTWARE.


global logP;

logP = 0;

startNode = this.torso;

compute_potential(this, -1, startNode, direction);

logProb = logP;

end


function compute_potential( this, parent, node, direction )
global logP;

for a = 1:this.nParts
    if (this.jointConnectionMatrix(node, a) > 0)&&(a ~= parent)
        k = a;
        
        if( ~this.occlusion(k) ) && ( ~this.occlusion(node) )
            
            modelInd = find(ismember( this.modelName, this.modelIndex{node}{k} ) == 1);
            
            if any(modelInd)
                nB = min(numel(this.z{k}), this.nBasis);
                
                if strcmp(direction, 'fwd')
                    thetaji = this.poseAbs(k) - this.poseAbs(node);
                    
                    ind = [ this.model{modelInd}.depCoeffInd(1:nB), this.model{modelInd}.sinDepInd, ...
                        this.model{modelInd}.cosDepInd, this.model{modelInd}.QxDepInd, this.model{modelInd}.QyDepInd, ...
                        this.model{modelInd}.refCoeffInd(1:nB) ];
                    
                    
                    Covariance = this.model{modelInd}.Covariance(ind, ind);
                    Mean = this.model{modelInd}.Mean(ind);
                    
                    [ pX pY] = this.part_center_to_joints( node, this.z{node}, ...
                        this.poseAbs(node), this.Ox(node), this.Oy(node) );
                    
                    jointIndi = this.jointConnectionMatrix(k, node);
                    Qxi = pX(jointIndi);
                    Qyi = pY(jointIndi);
                    
                    [ pX pY] = this.part_center_to_joints( k, this.z{k}, ...
                        this.poseAbs(k), this.Ox(k), this.Oy(k) );
                    jointIndj = this.jointConnectionMatrix(node, k);
                    Qxj = pX(jointIndj);
                    Qyj = pY(jointIndj);
                    
                    [ qjix qjiy ] = world_to_object(Qxj, Qyj, this.poseAbs(node), Qxi, Qyi);
                    
                    x = [ this.z{k}(1:nB)' sin(thetaji) cos(thetaji) qjix qjiy this.z{node}(1:nB)' ];
                    P = mvnpdf(x, Mean', Covariance);
                    
                    %fprintf('@DS log(P) from %d and %d: %f (qx= %f qy= %f) \n', node, k, log(P), qjix, qjiy);
                    
                    logP = logP + log(P);
                elseif strcmp(direction, 'bwd')
                    
                    modelInd = find(ismember( this.modelName, this.modelIndex{k}{node} ) == 1);
                    
                    thetaji = this.poseAbs(node) - this.poseAbs(k);
                    
                    ind = [ this.model{modelInd}.depCoeffInd(1:nB), this.model{modelInd}.sinDepInd, ...
                        this.model{modelInd}.cosDepInd, this.model{modelInd}.QxDepInd, this.model{modelInd}.QyDepInd, ...
                        this.model{modelInd}.refCoeffInd(1:nB) ];
                    
                    Covariance = this.model{modelInd}.Covariance(ind, ind);
                    Mean = this.model{modelInd}.Mean(ind);
                    
                    [ pX pY] = this.part_center_to_joints( k, this.z{k}, ...
                        this.poseAbs(k), this.Ox(k), this.Oy(k) );
                    
                    jointIndi = this.jointConnectionMatrix(node, k);
                    Qxi = pX(jointIndi);
                    Qyi = pY(jointIndi);
                    
                    [ pX pY] = this.part_center_to_joints( node, this.z{node}, ...
                        this.poseAbs(node), this.Ox(node), this.Oy(node) );
                    jointIndj = this.jointConnectionMatrix(k, node);
                    Qxj = pX(jointIndj);
                    Qyj = pY(jointIndj);
                    
                    [ qjix qjiy ] = world_to_object(Qxj, Qyj, this.poseAbs(k), Qxi, Qyi);
                    
                    x = [ this.z{node}(1:nB)' sin(thetaji) cos(thetaji) qjix qjiy this.z{k}(1:nB)' ];
                    
                    P = mvnpdf(x, Mean', Covariance);
                    
                    %fprintf('@DS log(P) from %d and %d: %f (qx= %f qy= %f)\n', k, node, log(P), qjix, qjiy);
                    
                    logP = logP + log(P);
                else
                    logP = NaN;
                end
                compute_potential( this, node, k, direction  );
            end
            
        end
    end
end
end

