
function [ mu_ab C_ab zInd sinInd cosInd qxInd qyInd H_aa ] = ...
    get_conditioned_potential( this, refInd, depInd, z_i, sin_ji, cos_ji, stick_j, nBdep )
% GET_CONDITIONED_POTENTIAL
% Returns the multivariate Gaussian (with mean mu_ab and covariance C_ab) 
% given the conditioning input variables
% Paper: "From Pictorial Structures to Deformable Structures", S. Zuffi, O.
% Freifeld, M. Black, CVPR 2012
% 
% Authors: Silvia Zuffi, Department of Computer Science, Brown University
% Contact: zuffi@cs.brown.edu
% $Date: 2012 $
% $Revision: $
%
% Copyright 2011-2012, Brown University, Providence, RI. USA
%
%                          All Rights Reserved
%
% All commercial use of this software, whether direct or indirect, is
% strictly prohibited including, without limitation, incorporation into in
% a commercial product, use in a commercial service, or production of other
% artifacts for commercial purposes.
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for research purposes is hereby granted without fee,
% provided that the above copyright notice appears in all copies and that
% both that copyright notice and this permission notice appear in
% supporting documentation, and that the name of the author and Brown
% University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission.
%
% For commercial uses contact the Technology Venture Office of Brown University
%
% THE AUTHOR AND BROWN UNIVERSITY DISCLAIM ALL WARRANTIES WITH REGARD TO
% THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
% FITNESS FOR ANY PARTICULAR PURPOSE.  IN NO EVENT SHALL THE AUTHOR OR
% BROWN UNIVERSITY BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
% DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
% PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
% ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
% THIS SOFTWARE.

model = this.model;
modelInd = find(ismember( this.modelName, this.modelIndex{refInd}{depInd} ) == 1);

C = model{modelInd}.Covariance;
mu = model{modelInd}.Mean;
nBref = numel(z_i);

ind = [model{modelInd}.depCoeffInd(1:nBdep), model{modelInd}.sinDepInd, model{modelInd}.cosDepInd, ...
    model{modelInd}.QxDepInd, model{modelInd}.QyDepInd, model{modelInd}.boneLengthDepInd, ...
    model{modelInd}.refCoeffInd(1:nBref) ];

C = C(ind, ind);
mu = mu(ind);

if isempty(nBdep) || nBdep == 0
    depCoeffInd = [];
    sinDepInd = 1;
else
    depCoeffInd = (1:nBdep); 
    sinDepInd = depCoeffInd(end)+1;
end
cosDepInd = sinDepInd+1;
QxDepInd = cosDepInd+1;
QyDepInd = QxDepInd+1;
boneLengthDepInd = QyDepInd+1;
refCoeffInd = (boneLengthDepInd+1:boneLengthDepInd+nBref);

allInd = (1:size(C,1));
bInd = [];
if numel(z_i)
    bInd = [ bInd, refCoeffInd ];
end
if numel(sin_ji) && numel(cos_ji)
    bInd = [ bInd, sinDepInd, cosDepInd ];
end
if numel(stick_j)
    bInd = [ bInd, boneLengthDepInd ];
end

aInd = setdiff(allInd, bInd);

conditioningValues = [z_i' sin_ji cos_ji stick_j];

%% Using the covariance matrix
Caa = C(aInd, aInd);
Cbb = C(bInd, bInd);
Cab = C(aInd, bInd);
Cba = C(bInd, aInd);

if isempty(bInd)
    C_ab = Caa;
    mu_ab = mu(aInd);
else
    C_ab = Caa - Cab * (Cbb \ Cba);
    mu_ab = mu(aInd) + Cab * (Cbb \ (conditioningValues' - mu(bInd)));    
end

H = inv(C);
H_aa = H(aInd, aInd);


zInd = depCoeffInd;
if numel(sin_ji) && numel(cos_ji)
    qxInd = QxDepInd - 2;
    qyInd = QyDepInd - 2;
    sinInd = [];
    cosInd = [];
else
    qxInd = QxDepInd;
    qyInd = QyDepInd;
    sinInd = sinDepInd;
    cosInd = cosDepInd;
end


end

