function [ poseAbs shape Ox Oy Qx Qy p1x p1y p2x p2y ] = get_mean_pose_shape( this )
% GET_MEAN_POSE_SHAPE
% Returns the mean parameters for the model
%
% Paper: "From Pictorial Structures to Deformable Structures", S. Zuffi, O.
% Freifeld, M. Black, CVPR 2012
% Authors: Silvia Zuffi, Department of Computer Science, Brown University
% Contact: zuffi@cs.brown.edu
% $Date: 2012 $
% $Revision: $
%
% Copyright 2011-2012, Brown University, Providence, RI. USA
%
%                          All Rights Reserved
%
% All commercial use of this software, whether direct or indirect, is
% strictly prohibited including, without limitation, incorporation into in
% a commercial product, use in a commercial service, or production of other
% artifacts for commercial purposes.
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for research purposes is hereby granted without fee,
% provided that the above copyright notice appears in all copies and that
% both that copyright notice and this permission notice appear in
% supporting documentation, and that the name of the author and Brown
% University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission.
%
% For commercial uses contact the Technology Venture Office of Brown University
%
% THE AUTHOR AND BROWN UNIVERSITY DISCLAIM ALL WARRANTIES WITH REGARD TO
% THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
% FITNESS FOR ANY PARTICULAR PURPOSE.  IN NO EVENT SHALL THE AUTHOR OR
% BROWN UNIVERSITY BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
% DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
% PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
% ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
% THIS SOFTWARE.


poseAbs = zeros(this.nParts, 1);
Ox = zeros(this.nParts, 1);
Oy = zeros(this.nParts, 1);
Qx = zeros(this.nParts, 1);
Qy = zeros(this.nParts, 1);

% p1 and p2
p1x = zeros(this.nParts, 1);
p1y = zeros(this.nParts, 1);
p2x = zeros(this.nParts, 1);
p2y = zeros(this.nParts, 1);

% initial orientation for the torso
poseAbs(1) = pi/2;
shape{1} = zeros(length(this.model{this.torsoToHead}.refCoeffInd), 1);

% Contour points
m = this.torsoToHead;
B = this.model{m}.eigVectors{1};
Sample = B * shape{1} + this.model{m}.eigMean{1};
p2xi = Sample(end-2*this.nJointsPart(1)+3);
p2yi = Sample(end-2*this.nJointsPart(1)+4);
p1xi = Sample(end-2*this.nJointsPart(1)+1);
p1yi = Sample(end-2*this.nJointsPart(1)+2);
[ p2x(1) p2y(1) ] = object_to_world(p2xi, p2yi, poseAbs(1), Ox(1), Oy(1));
[ p1x(1) p1y(1) ] = object_to_world(p1xi, p1yi, poseAbs(1), Ox(1), Oy(1));

Qx(1) = p1x(1);
Qy(1) = p1y(1);

for j=2:this.nParts
    
    parent = this.Parent{j};
    m = find(ismember( this.modelName, this.modelIndex{parent}{j} ) == 1);

    z_i = zeros(length(this.model{m}.refCoeffInd), 1);
    
    [ shape{j}, sin_j, cos_j, Ojx, Ojy, Qjx, Qjy ] = ...
        this.predict_part_conditioned( m, z_i, [], [], [], 0 );

    % Part center and joints in global coordinates
    [ Ox(j) Oy(j) ] = object_to_world(Ojx, Ojy, poseAbs(parent), Ox(parent), Oy(parent));
    [ Qx(j) Qy(j) ] = object_to_world(Qjx, Qjy, poseAbs(parent), Ox(parent), Oy(parent));
    Angle = atan2(sin_j, cos_j);
    poseAbs(j) = poseAbs(parent) + Angle;

    % Contour points
    B = this.model{m}.eigVectors{2};
    Sample = B * shape{j} + this.model{m}.eigMean{2};
    p2xj = Sample(end-1);
    p2yj = Sample(end);
    p1xj = Sample(end-3);
    p1yj = Sample(end-2);
    [ p2x(j) p2y(j) ] = object_to_world(p2xj, p2yj, poseAbs(j), Ox(j), Oy(j));
    [ p1x(j) p1y(j) ] = object_to_world(p1xj, p1yj, poseAbs(j), Ox(j), Oy(j));
end

end


