function [ points angles ] = get_part_contour_points_and_angles( this, ind, z, theta, Ox, Oy )
% GET_PART_CONTOUR_POINTS_AND_ANGLES
% Returns the coordinates of the pints (in an array of YX coordinates, and
% the angle of the normal at the point)
%
% Paper: "From Pictorial Structures to Deformable Structures", S. Zuffi, O.
% Freifeld, M. Black, CVPR 2012
% Authors: Silvia Zuffi, Department of Computer Science, Brown University
% Contact: zuffi@cs.brown.edu
% $Date: 2012 $
% $Revision: $
%
% Copyright 2011-2012, Brown University, Providence, RI. USA
%
%                          All Rights Reserved
%
% All commercial use of this software, whether direct or indirect, is
% strictly prohibited including, without limitation, incorporation into in
% a commercial product, use in a commercial service, or production of other
% artifacts for commercial purposes.
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for research purposes is hereby granted without fee,
% provided that the above copyright notice appears in all copies and that
% both that copyright notice and this permission notice appear in
% supporting documentation, and that the name of the author and Brown
% University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission.
%
% For commercial uses contact the Technology Venture Office of Brown University
%
% THE AUTHOR AND BROWN UNIVERSITY DISCLAIM ALL WARRANTIES WITH REGARD TO
% THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
% FITNESS FOR ANY PARTICULAR PURPOSE.  IN NO EVENT SHALL THE AUTHOR OR
% BROWN UNIVERSITY BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
% DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
% PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
% ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
% THIS SOFTWARE.

[ ~, ~, X, Y ] = get_part_points_with_parameters( this, ind, z, theta, Ox, Oy );

% Angles need to be the direction of the normal at each point. First
% compute the direction of the tangent, and then rotate of -pi/2

Y_1 = circshift(Y, 1);
X_1 = circshift(X, 1);

dx = X - X_1;
dy = Y - Y_1;

tangentAngles = atan2(dy, dx);
angles = double(tangentAngles + pi/2 * ones(size(tangentAngles)));

[X Y] = this.world_to_image(X, Y);
points = [round(Y), round(X)];

end