function [ z_j, sin_j, cos_j, Ojx_i, Ojy_i, Qjx_i, Qjy_i ] = get_part_sample(this, model, Mean, Covariance, z_i)
% GET_PART_SAMPLE

% Paper: "From Pictorial Structures to Deformable Structures", S. Zuffi, O.
% Freifeld, M. Black, CVPR 2012
% Authors: Silvia Zuffi, Department of Computer Science, Brown University
% Contact: zuffi@cs.brown.edu
% $Date: 2012 $
% $Revision: $
%
% Copyright 2011-2012, Brown University, Providence, RI. USA
%
%                          All Rights Reserved
%
% All commercial use of this software, whether direct or indirect, is
% strictly prohibited including, without limitation, incorporation into in
% a commercial product, use in a commercial service, or production of other
% artifacts for commercial purposes.
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for research purposes is hereby granted without fee,
% provided that the above copyright notice appears in all copies and that
% both that copyright notice and this permission notice appear in
% supporting documentation, and that the name of the author and Brown
% University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission.
%
% For commercial uses contact the Technology Venture Office of Brown University
%
% THE AUTHOR AND BROWN UNIVERSITY DISCLAIM ALL WARRANTIES WITH REGARD TO
% THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
% FITNESS FOR ANY PARTICULAR PURPOSE.  IN NO EVENT SHALL THE AUTHOR OR
% BROWN UNIVERSITY BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
% DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
% PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
% ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
% THIS SOFTWARE.

mu_ab = mvnrnd(Mean, Covariance)'; 
z_j = mu_ab(model.depCoeffInd);
sin_j = mu_ab(model.sinDepInd);
cos_j = mu_ab(model.cosDepInd);
qx = mu_ab(model.QxDepInd);
qy = mu_ab(model.QyDepInd);

% Compute the part center. I need the joint location of both parts in
% their local coordinate system
B = model.eigVectors{1};
m = model.eigMean{1};
points = B*z_i+m;
ind = this.jointConnectionMatrix(model.depPartInd, model.refPartInd);
Qix_i = points(2*model.nPoints{1}+2*(ind-1)+1);
Qiy_i = points(2*model.nPoints{1}+2*(ind-1)+2);

B = model.eigVectors{2};
m = model.eigMean{2};
points = B*z_j+m;
ind = this.jointConnectionMatrix(model.refPartInd, model.depPartInd);
Qjx_j = points(2*model.nPoints{2}+2*(ind-1)+1);
Qjy_j = points(2*model.nPoints{2}+2*(ind-1)+2);

Qjx_i = Qix_i + qx; 
Qjy_i = Qiy_i + qy; 

Ojx_j = -Qjx_j;
Ojy_j = -Qjy_j;

Angle = atan2(sin_j, cos_j);
[ Ojx_i Ojy_i ] = object_to_world(Ojx_j, Ojy_j, Angle, Qjx_i, Qjy_i);

end

