function [ z_j, theta_j0, Ojx_0, Ojy_0, Qjx_0, Qjy_0, Qx, Qy ] = get_random_child( this, child, node, z_i, theta_i0, Oix_0, Oiy_0, stick_j, theta_j0)
% GET_RANDOM_CHILD
% Computes a child for the part node given parameters
%
% Paper: "From Pictorial Structures to Deformable Structures", S. Zuffi, O.
% Freifeld, M. Black, CVPR 2012
% Authors: Silvia Zuffi, Department of Computer Science, Brown University
% Contact: zuffi@cs.brown.edu
% $Date: 2012 $
% $Revision: $
%
% Copyright 2011-2012, Brown University, Providence, RI. USA
%
%                          All Rights Reserved
%
% All commercial use of this software, whether direct or indirect, is
% strictly prohibited including, without limitation, incorporation into in
% a commercial product, use in a commercial service, or production of other
% artifacts for commercial purposes.
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for research purposes is hereby granted without fee,
% provided that the above copyright notice appears in all copies and that
% both that copyright notice and this permission notice appear in
% supporting documentation, and that the name of the author and Brown
% University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission.
%
% For commercial uses contact the Technology Venture Office of Brown University
%
% THE AUTHOR AND BROWN UNIVERSITY DISCLAIM ALL WARRANTIES WITH REGARD TO
% THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
% FITNESS FOR ANY PARTICULAR PURPOSE.  IN NO EVENT SHALL THE AUTHOR OR
% BROWN UNIVERSITY BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
% DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
% PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
% ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
% THIS SOFTWARE.


modelInd = find(ismember( this.modelName, this.modelIndex{node}{child} ) == 1);

if ~isempty(theta_j0)

    theta_ji = theta_j0 - theta_i0;
    [ z_j, ~, ~, Ojx, Ojy, Qjx, Qjy ] = ...
        this.predict_part_conditioned( modelInd, z_i, sin(theta_ji), cos(theta_ji), stick_j, 1 );
    
else
    [ z_j, sin_theta_ji, cos_theta_ji, Ojx, Ojy, Qjx, Qjy ] = ...
        this.predict_part_conditioned( modelInd, z_i, [], [], stick_j, 1 );
    theta_ji = atan2(sin_theta_ji, cos_theta_ji);
    
    theta_j0 = theta_ji + theta_i0;
end

[ Ojx_0 Ojy_0 ] = object_to_world(Ojx, Ojy, theta_i0, Oix_0, Oiy_0);
[ Qjx_0 Qjy_0 ] = object_to_world(Qjx, Qjy, theta_i0, Oix_0, Oiy_0);

[ Qx Qy ] = this.part_center_to_joints( child, z_j, theta_j0, Ojx_0, Ojy_0 );

end

