function [ Ox Oy pX pY X1 Y1] = joint_to_part_center_joints_points( this, ind, z, Angle, Q1x, Q1y, Q2x, Q2y )
% Returns the part center given shape parameters, angle and one joint. The
% joint can be the proximal joint (p1) or the distal joint (p2)
% also returns the joints and part points

nJointsPart = this.nJointsPart(ind);
B = this.B{ind};
M = this.M{ind};
Z = zeros(size(B,2), 1);
Z(1:length(z)) = z;
Sample = B * Z + M;

X = Sample(1:2:end);
Y = Sample(2:2:end);

% joints coordinates of p1 and p2 in local coo system
pXlocal = X(end-nJointsPart+1:end);
pYlocal = Y(end-nJointsPart+1:end);

% check if the input joint is p1 or p2
if (any(Q2x) && any(Q2y))
    qXlocal = pXlocal(2);
    qYlocal = pYlocal(2);
    Qx = Q2x;
    Qy = Q2y;
else    
    qXlocal = pXlocal(1);
    qYlocal = pYlocal(1);
    Qx = Q1x;
    Qy = Q1y;
end

%% Compute center location from joint location
oXlocal = -qXlocal;
oYlocal = -qYlocal;


[ Ox Oy ] = object_to_world(oXlocal, oYlocal, Angle, Qx, Qy);

[ X Y ] = object_to_world(X, Y, Angle, Ox, Oy);

X1 = X(1:end-nJointsPart);
Y1 = Y(1:end-nJointsPart);

pX = X(end-nJointsPart+1:end);
pY = Y(end-nJointsPart+1:end);

end

