function [ Ox Oy pX pY X1 Y1] = joint_to_part_center_joints_points_multiple( this, ind, z, Angle, Q1x, Q1y, Q2x, Q2y )
% JOINT_TO_PART_CENTER_JOINTS_POINTS_MULTIPLE
% Returns the part center given shape parameters, angle and one joint. The
% joint can be the proximal joint (p1) or the distal joint (p2)
% also returns the joints and part points

% Paper: "From Pictorial Structures to Deformable Structures", S. Zuffi, O.
% Freifeld, M. Black, CVPR 2012
% Authors: Silvia Zuffi, Department of Computer Science, Brown University
% Contact: zuffi@cs.brown.edu
% $Date: 2012 $
% $Revision: $
%
% Copyright 2011-2012, Brown University, Providence, RI. USA
%
%                          All Rights Reserved
%
% All commercial use of this software, whether direct or indirect, is
% strictly prohibited including, without limitation, incorporation into in
% a commercial product, use in a commercial service, or production of other
% artifacts for commercial purposes.
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for research purposes is hereby granted without fee,
% provided that the above copyright notice appears in all copies and that
% both that copyright notice and this permission notice appear in
% supporting documentation, and that the name of the author and Brown
% University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission.
%
% For commercial uses contact the Technology Venture Office of Brown University
%
% THE AUTHOR AND BROWN UNIVERSITY DISCLAIM ALL WARRANTIES WITH REGARD TO
% THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
% FITNESS FOR ANY PARTICULAR PURPOSE.  IN NO EVENT SHALL THE AUTHOR OR
% BROWN UNIVERSITY BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
% DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
% PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
% ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
% THIS SOFTWARE.

N = length(Angle);

nJointsPart = this.nJointsPart(ind);
B = this.B{ind};
M = this.M{ind};
Z = zeros(size(B,2), N);
Z(1:size(z,1), :) = z;
Sample = B * Z + repmat(M, [1, N]);

X = Sample(1:2:end, :);
Y = Sample(2:2:end, :);

% Joints coordinates of p1 and p2 in local coo system
pXlocal = X(end-nJointsPart+1:end, :);
pYlocal = Y(end-nJointsPart+1:end, :);

% Check if the input joint is p1 or p2
if (any(Q2x) && any(Q2y))
    qXlocal = pXlocal(2, :);
    qYlocal = pYlocal(2, :);
    Qx = Q2x;
    Qy = Q2y;
else    
    qXlocal = pXlocal(1, :);
    qYlocal = pYlocal(1, :);
    Qx = Q1x;
    Qy = Q1y;
end

% Compute center location from joint location
oXlocal = -qXlocal;
oYlocal = -qYlocal;

[ Ox Oy ] = object_to_world(oXlocal, oYlocal, Angle, Qx, Qy);
[ X Y ] = object_to_world_matrix(X, Y, Angle, Ox, Oy);

X1 = X(1:end-nJointsPart, :);
Y1 = Y(1:end-nJointsPart, :);

pX = X(end-nJointsPart+1:end, :);
pY = Y(end-nJointsPart+1:end, :);

end

