function [ B ] = make_mask_image( this )
% MAKE_MASK_IMAGE
% Makes a mask image with the current model
%
% Paper: "From Pictorial Structures to Deformable Structures", S. Zuffi, O.
% Freifeld, M. Black, CVPR 2012
% Authors: Silvia Zuffi, Department of Computer Science, Brown University
% Contact: zuffi@cs.brown.edu
% $Date: 2012 $
% $Revision: $
%
% Copyright 2011-2012, Brown University, Providence, RI. USA
%
%                          All Rights Reserved
%
% All commercial use of this software, whether direct or indirect, is
% strictly prohibited including, without limitation, incorporation into in
% a commercial product, use in a commercial service, or production of other
% artifacts for commercial purposes.
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for research purposes is hereby granted without fee,
% provided that the above copyright notice appears in all copies and that
% both that copyright notice and this permission notice appear in
% supporting documentation, and that the name of the author and Brown
% University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission.
%
% For commercial uses contact the Technology Venture Office of Brown University
%
% THE AUTHOR AND BROWN UNIVERSITY DISCLAIM ALL WARRANTIES WITH REGARD TO
% THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
% FITNESS FOR ANY PARTICULAR PURPOSE.  IN NO EVENT SHALL THE AUTHOR OR
% BROWN UNIVERSITY BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
% DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
% PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
% ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
% THIS SOFTWARE.

DISPLAY = 0;

B = zeros(this.imSize(1), this.imSize(2));

for i = 1:this.nParts
    if ~this.occlusion(i)
        [ ~, ~, X, Y ] = this.get_part_points( i );
        [ X Y ] = this.world_to_image( X, Y );
        if ismember(i, [7, 8])
            B = B | poly2mask(double(X(1:60)), double(Y(1:60)), this.imSize(1), this.imSize(2));
            B = B | poly2mask(double(X(63:end)), double(Y(63:end)), this.imSize(1), this.imSize(2));
        else
            if ismember(i, [9, 10])
                B = B | poly2mask(double(X(1:60)), double(Y(1:60)), this.imSize(1), this.imSize(2));
                B = B | poly2mask(double(X(63:end)), double(Y(63:end)), this.imSize(1), this.imSize(2));
                
            else
                B = B | poly2mask(double(X), double(Y), this.imSize(1), this.imSize(2));
            end
        end
    end
end

if DISPLAY
    figure
    imagesc(B)
end

end

