function set_DS_as_random_puppet( this, startNode, modelInd, Ox, Oy )
% SET_DS_AS_RANDOM_PUPPET
%
% Paper: "From Pictorial Structures to Deformable Structures", S. Zuffi, O.
% Freifeld, M. Black, CVPR 2012
% Authors: Silvia Zuffi, Department of Computer Science, Brown University
% Contact: zuffi@cs.brown.edu
% $Date: 2012 $
% $Revision: $
%
% Copyright 2011-2012, Brown University, Providence, RI. USA
%
%                          All Rights Reserved
%
% All commercial use of this software, whether direct or indirect, is
% strictly prohibited including, without limitation, incorporation into in
% a commercial product, use in a commercial service, or production of other
% artifacts for commercial purposes.
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for research purposes is hereby granted without fee,
% provided that the above copyright notice appears in all copies and that
% both that copyright notice and this permission notice appear in
% supporting documentation, and that the name of the author and Brown
% University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission.
%
% For commercial uses contact the Technology Venture Office of Brown University
%
% THE AUTHOR AND BROWN UNIVERSITY DISCLAIM ALL WARRANTIES WITH REGARD TO
% THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
% FITNESS FOR ANY PARTICULAR PURPOSE.  IN NO EVENT SHALL THE AUTHOR OR
% BROWN UNIVERSITY BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
% DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
% PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
% ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
% THIS SOFTWARE.

M = this.model{modelInd}.Mean;
if this.nBasis(startNode) > 0
    mu_ab = mvnrnd(M, this.model{modelInd}.Covariance);
    z_i = mu_ab(this.model{modelInd}.refCoeffInd);
    z_i = z_i(1:this.nBasis(startNode));
else
    z_i = [];
end

startAngle = rand()*pi;

this.z{startNode} = z_i;
this.Ox(startNode) = Ox;
this.Oy(startNode) = Oy;
this.poseAbs(startNode) = startAngle;
[ Qx Qy ] = this.part_center_to_joints( startNode, z_i, startAngle, Ox, Oy );
[ this.Qx(startNode) this.Qy(startNode) ] = deal(Qx(1), Qy(1));

[ this.p1x(startNode) this.p1y(startNode) ] = deal(Qx(1), Qy(1));
[ this.p2x(startNode) this.p2y(startNode) ] = deal(Qx(2), Qy(2));


get_child(this, -1, startNode, z_i, startAngle, Ox, Oy);



end


function get_child( this, parent, node, z_i, theta_i0, Oix_0, Oiy_0)
    
    for a = 1:this.nParts
        if (this.jointConnectionMatrix(node, a) > 0)&&(a ~= parent)
            k = a;
            modelInd = find(ismember( this.modelName, this.modelIndex{node}{k} ) == 1);
            if any(modelInd)

                
                [ z_j, sinTheta_ji, cosTheta_ji, Ojx, Ojy, Qjx, Qjy ] = ...
                    this.predict_part_conditioned( modelInd, z_i, [], [], [], 1 );
                    
                theta_ji = atan2(sinTheta_ji, cosTheta_ji); 
                theta_j0 = theta_ji + theta_i0;
                
                [ Ojx_0 Ojy_0 ] = object_to_world(Ojx, Ojy, theta_i0, Oix_0, Oiy_0);
                [ Qjx_0 Qjy_0 ] = object_to_world(Qjx, Qjy, theta_i0, Oix_0, Oiy_0);

                this.z{k} = z_j;
                this.Ox(k) = Ojx_0;
                this.Oy(k) = Ojy_0;
                this.Qx(k) = Qjx_0(1);
                this.Qy(k) = Qjy_0(1);
                this.poseAbs(k) = theta_j0;
                
                [ Qx Qy ] = this.part_center_to_joints( k, z_j, theta_j0, Ojx_0, Ojy_0 );
                [ this.p1x(k) this.p1y(k) ] = deal(Qx(1), Qy(1));
                [ this.p2x(k) this.p2y(k) ] = deal(Qx(2), Qy(2));

 
                get_child( this, node, k, z_j, theta_j0, Ojx_0, Ojy_0 );
            end
        end
    end
end

