function [ Ppart ] = set_me_as_mean( this, Ox, Oy )
% SET_ME_AS_MEAN
%
% Paper: "From Pictorial Structures to Deformable Structures", S. Zuffi, O.
% Freifeld, M. Black, CVPR 2012
% Authors: Silvia Zuffi, Department of Computer Science, Brown University
% Contact: zuffi@cs.brown.edu
% $Date: 2012 $
% $Revision: $
%
% Copyright 2011-2012, Brown University, Providence, RI. USA
%
%                          All Rights Reserved
%
% All commercial use of this software, whether direct or indirect, is
% strictly prohibited including, without limitation, incorporation into in
% a commercial product, use in a commercial service, or production of other
% artifacts for commercial purposes.
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for research purposes is hereby granted without fee,
% provided that the above copyright notice appears in all copies and that
% both that copyright notice and this permission notice appear in
% supporting documentation, and that the name of the author and Brown
% University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission.
%
% For commercial uses contact the Technology Venture Office of Brown University
%
% THE AUTHOR AND BROWN UNIVERSITY DISCLAIM ALL WARRANTIES WITH REGARD TO
% THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
% FITNESS FOR ANY PARTICULAR PURPOSE.  IN NO EVENT SHALL THE AUTHOR OR
% BROWN UNIVERSITY BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
% DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
% PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
% ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
% THIS SOFTWARE.

this.poseAbs(this.torso) = pi/2;
this.Ox(this.torso) = 0;
this.Oy(this.torso) = 0;
this.z{this.torso} =  this.model{this.torsoToHead}.Mean(this.model{this.torsoToHead}.refCoeffInd);

Ppart = ones(this.nParts, 1);

modelInd = this.torsoToHead;
ind = this.model{modelInd}.refCoeffInd;
Covariance = this.model{modelInd}.Covariance(ind, ind);
Mean = this.model{modelInd}.Mean(ind);

Ppart(this.torso) = mvnpdf(Mean, Mean, Covariance);


for j=2:this.nParts
    parent = this.Parent{j};
    m = find(ismember( this.modelName, this.modelIndex{parent}{j} ) == 1);
    [ z_j, sin_j, cos_j, Ojx, Ojy ] = ...
        this.predict_part_conditioned( m, this.z{parent}, [], [], [], 0 );
    this.z{j} =  z_j; 
    Angle = atan2(sin_j, cos_j);
    this.poseAbs(j) = this.poseAbs(parent) + Angle;
    
    [ this.Ox(j) this.Oy(j) ] = object_to_world(Ojx, Ojy, this.poseAbs(parent), this.Ox(parent), this.Oy(parent));
    
end

this.Ox = this.Ox + Ox * ones(size(this.Ox));
this.Oy = this.Oy + Oy * ones(size(this.Oy));

end

