function y = my_mvnpdf(X, Mu, Sigma)
%   Silvia: All the check removed for performance

%   Copyright 1993-2008 The MathWorks, Inc.
%   $Revision: 1.2.4.8 $  $Date: 2008/02/29 13:12:08 $

% Get size of data.  Column vectors provisionally interpreted as multiple scalar data.
[ n, d ] = size(X);

n2 = size(Mu, 1);
if n2 == n % lengths match
    X0 = X - Mu;
elseif n2 == 1 % mean is a single row, rep it out to match data
    X0 = bsxfun(@minus,X,Mu);
end

% Single covariance matrix
if ndims(Sigma) == 2
    sz = size(Sigma);
    if sz(1)==1 && sz(2)>1
        % Just the diagonal of Sigma has been passed in.
        sz(1) = sz(2);
        sigmaIsDiag = true;
    else
        sigmaIsDiag = false;
    end
    
    % Special case: if Sigma is supplied, then use it to try to interpret
    % X and Mu as row vectors if they were both column vectors.
    if (d == 1) && (numel(X) > 1) && (sz(1) == n)
        X0 = X0';
    end
    if sigmaIsDiag
        if any(Sigma<=0)
            error('stats:mvnpdf:BadDiagSigma', ...
                'All elements of diagonal SIGMA must be positive.');
        end
        R = sqrt(Sigma);
        xRinv = bsxfun(@rdivide,X0,R);
        logSqrtDetSigma = sum(log(R));
    else
        
        % Make sure Sigma is a valid covariance matrix
        [R,err] = cholcov(Sigma,0);
        if err ~= 0
            error('stats:mvnpdf:BadCovariance', ...
                'SIGMA must be symmetric and positive definite.');
        end
        % Create array of standardized data, and compute log(sqrt(det(Sigma)))
        xRinv = X0 / R;
        logSqrtDetSigma = sum(log(diag(R)));
    end
end

% The quadratic form is the inner products of the standardized data
quadform = sum(xRinv.^2, 2);

y = exp(-0.5*quadform - logSqrtDetSigma - d*log(2*pi)/2);

end